@@ -28,7 +28,7 @@ use base 'Algorithm::Dependency';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.100';
+	$VERSION = '1.104';
 }
 
 
@@ -104,7 +104,7 @@ For general comments, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
 
 =head1 SEE ALSO
 
@@ -112,7 +112,7 @@ L<Algorithm::Dependency>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 - 2005 Adam Kennedy. All rights reserved.
+Copyright (c) 2003 - 2005 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
