@@ -20,11 +20,11 @@ L<Algorithm::Dependency> package.
 
 use strict;
 use Algorithm::Dependency ();
-use Params::Util qw{_IDENTIFIER _SET};
+use Params::Util qw{_SET};
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.100';
+	$VERSION = '1.104';
 }
 
 
@@ -136,7 +136,7 @@ the named item does not exist in the source.
 
 sub item {
 	my $self = shift;
-	my $id   = _IDENTIFIER(shift)  or return undef;
+	my $id   = (defined $_[0] and ! ref $_[0] and $_[0] ne '') ? shift : return undef;
 	$self->{loaded} or $self->load or return undef;
 
 	# Return the item (or undef)
@@ -245,7 +245,7 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm-Dependency>
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
 
 =head1 SEE ALSO
 
@@ -253,7 +253,7 @@ L<Algorithm::Dependency>, L<Algorithm::Dependency::Source::File>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 - 2005 Adam Kennedy. All rights reserved.
+Copyright (c) 2003 - 2005 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
